# AskAI

Ask OpenAI your question from the command line and get a response. Super janky right now.

# Installation

    pip install askit

# Add API key first time use

    ask api your-openai-key-goes-here

# Usage

    ask it "Is this a well formulated question for openAI?"

# Notes
You need to have your question in a string format, and you must end your question with a question mark or it won't work.

"Questions must look like this?"

This is super janky. Feedback welcomed.